summaryrefslogtreecommitdiff
path: root/app/User.php
diff options
context:
space:
mode:
authorGreg Roach <fisharebest@webtrees.net>2018-08-09 11:26:30 +0100
committerGreg Roach <fisharebest@webtrees.net>2018-08-09 14:42:22 +0100
commitb0b72ea46df4d8654cf8b9a04f9cc009b0af8be3 (patch)
treea31b3c5f402e14ea9686d4c752c864c382a5d57d /app/User.php
parente68f0c37c9254b1c78f7dabfd289645a743d67c9 (diff)
downloadwebtrees-b0b72ea46df4d8654cf8b9a04f9cc009b0af8be3.tar.gz
webtrees-b0b72ea46df4d8654cf8b9a04f9cc009b0af8be3.tar.bz2
webtrees-b0b72ea46df4d8654cf8b9a04f9cc009b0af8be3.zip
Wrong case for classes, functions and namespaces
Diffstat (limited to 'app/User.php')
-rw-r--r--app/User.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/app/User.php b/app/User.php
index 896d6cd521..90cef137a9 100644
--- a/app/User.php
+++ b/app/User.php
@@ -17,7 +17,7 @@ declare(strict_types=1);
namespace Fisharebest\Webtrees;
-use stdclass;
+use stdClass;
/**
* Provide an interface to the wt_user table.
@@ -45,7 +45,7 @@ class User
/**
* Create a new user object from a row in the database.
*
* @param stdclass $user A row from the wt_user table
*/
public function __construct(stdClass $user)
{
@@ -45,7 +45,7 @@ class User
* Create a new user object from a row in the database.
*
- * @param stdclass $user A row from the wt_user table
+ * @param stdClass $user A row from the wt_user table
*/
public function __construct(stdClass $user)